@@ -3,8 +3,9 @@
 #include "bible_text_source.h"
 #include "infinite_scroll.h"
 #include "search_dialog.h"
-#include "select_dialog.h"
 #include "search_results.h"
+#include "select_dialog.h"
+#include "settings_dialog.h"
 
 #include <iostream>
 #include <mce/mode-names.h>
@@ -33,12 +34,10 @@ MainWindow::MainWindow() : QMainWindow(NULL)
 	int chapter = settings.value("initial/chapter", 0).toInt();
 	int verse = settings.value("initial/verse", 0).toInt();
 	mBible = getBibleInfo(translation);
-	TextSource* bibleSource = getBibleTextSource(mBible, book);
 
 	QFrame* frame = new QFrame;
 	mLayout = new QHBoxLayout;
-	mpViewer = new InfiniteScrollViewer(this, bibleSource, chapter,
-										verse, "", mShowShortTitle);
+    mpViewer = createViewer(book, chapter, verse);
 	mLayout->addWidget(mpViewer);
 	mSearchResults = new SearchResultsFrame();
 	mLayout->addWidget(mSearchResults);
@@ -91,6 +90,7 @@ void MainWindow::createMenu()
 	menuBar()->addAction("Go to Verse", this, SLOT(onSelectVerse()));
 	menuBar()->addAction("Select Translation", this, SLOT(selectTranslation()));
 	menuBar()->addAction("Search", this, SLOT(onSearch()));
+	menuBar()->addAction("Settings", this, SLOT(onSettings()));
 }
 
 void MainWindow::replaceViewer(InfiniteScrollViewer* viewer)
@@ -170,14 +170,8 @@ void MainWindow::selectVerse(QString startingFilter)
 			startSearch(result.search_GetText());
 			break;
 		case SelectResult::Type_SelectedVerse:
-			TextSource* bibleSource = getBibleTextSource(mBible,
-													result.verse_GetBook());
-			InfiniteScrollViewer* viewer = \
-				new InfiniteScrollViewer(this, bibleSource,
-										result.verse_GetChapter(), 0,
-										"", mShowShortTitle);
-
-			replaceViewer(viewer);
+			QString book = mpViewer->getSourceName();
+			replaceViewer(createViewer(book, result.verse_GetChapter(), 0));
 			mSearchResults->hideResults();
 			break;
 		}
@@ -199,6 +193,16 @@ void MainWindow::startSearch(QString text)
 		search(dlg.getSearchText(), dlg.getSearchScope());
 }
 
+InfiniteScrollViewer* MainWindow::createViewer(QString book, int chapter,
+											int verse)
+{
+	TextSource* bibleSource = getBibleTextSource(mBible, book);
+	return new InfiniteScrollViewer(this, bibleSource,
+									shouldUseNewLineForVerses(),
+									getTextFontSize(),
+									chapter, verse, "", mShowShortTitle);
+}
+
 void MainWindow::selectTranslation()
 {
 	QString translation;
@@ -209,12 +213,7 @@ void MainWindow::selectTranslation()
 		int verse = mpViewer->getCurrentParagraph();
 
 		mBible = getBibleInfo(translation);
-		TextSource* bibleSource = getBibleTextSource(mBible, bookName);
-		InfiniteScrollViewer* viewer = \
-			new InfiniteScrollViewer(this, bibleSource, chapter,
-									verse, "", mShowShortTitle);
-
-		replaceViewer(viewer);
+		replaceViewer(createViewer(bookName, chapter, verse));
 		mSearchResults->hideResults();
 	}
 }
@@ -226,17 +225,26 @@ void MainWindow::onSearch()
 		search(dlg.getSearchText(), dlg.getSearchScope());
 }
 
+void MainWindow::onSettings()
+{
+	SettingsDialog dlg(this);
+	if (dlg.exec() == QDialog::Accepted)
+	{
+		QString bookName = mpViewer->getSourceName();
+		int chapter = mpViewer->getCurrentSection();
+		int verse = mpViewer->getCurrentParagraph();
+
+		replaceViewer(createViewer(bookName, chapter, verse));
+		mSearchResults->hideResults();
+	}
+		
+}
+
 void MainWindow::goToVerse(QString verse)
 {
 	Key key = mBible->getKeyForString(verse);
 
-	TextSource* bibleSource = getBibleTextSource(mBible, key.mBook);
-	InfiniteScrollViewer* viewer = \
-		new InfiniteScrollViewer(this, bibleSource, key.mChapter,
-								key.mVerse, mCurrentSearchText,
-								mShowShortTitle);
-
-	replaceViewer(viewer);
+	replaceViewer(createViewer(key.mBook, key.mChapter, key.mVerse));
 }
 void MainWindow::orientationChanged(const QString& newOrientation)
 {
