@@ -35,10 +35,13 @@ protected:
 	void search(QString text, QString scope);
 	void startSearch(QString text);
 
+	InfiniteScrollViewer* createViewer(QString book, int chapter, int verse);
+
 protected slots:
 	void onSelectVerse();
 	void selectTranslation();
 	void onSearch();
+	void onSettings();
 	void goToVerse(QString verse);
 	void orientationChanged(const QString& newOrientation);
 
